[Synopsis-changes] Synopsis/Synopsis/Synopsis/Formatters/HTML/Pages RawFilePages.py,1.10,1.11

Stefan Seefeld stefan at synopsis.fresco.org
Sat Nov 15 19:51:44 UTC 2003


Update of /cvs/synopsis/Synopsis/Synopsis/Formatters/HTML/Pages
In directory frida:/tmp/cvs-serv5005/Synopsis/Formatters/HTML/Pages

Modified Files:
	RawFilePages.py 
Log Message:
refactoring

Index: RawFilePages.py
===================================================================
RCS file: /cvs/synopsis/Synopsis/Synopsis/Formatters/HTML/Pages/RawFilePages.py,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -p -d -r1.10 -r1.11
--- RawFilePages.py	15 Nov 2003 19:01:53 -0000	1.10
+++ RawFilePages.py	15 Nov 2003 19:51:42 -0000	1.11
@@ -9,13 +9,12 @@
 
 from Synopsis.Processor import Parameter
 from Synopsis import AST, Util
-from Synopsis.Formatters.HTML.Part import Page
-from Synopsis.Formatters.HTML import ASTFormatter
+from Synopsis.Formatters.HTML.Page import Page
 from Synopsis.Formatters.HTML.Tags import *
 
 import time, os, stat, os.path, string
 
-class RawFilePages(Page):
+class RawFile(Page):
    """A module for creating a page for each file with hyperlinked source"""
 
    exclude = Parameter([], 'TODO: define an exclusion mechanism (glob based ?)')
@@ -27,13 +26,13 @@ class RawFilePages(Page):
       self.__files = None
 
    def filename(self):
       """since RawFilePages generates a whole file hierarchy, this method returns the current filename,
       which may change over the lifetime of this object"""
 
       return self.__filename
 
    def title(self):
       """since RawFilePages generates a while file hierarchy, this method returns the current title,
       which may change over the lifetime of this object"""
 
       return self.__title
@@ -27,13 +26,13 @@ class RawFilePages(Page):
 
    def filename(self):
-      """since RawFilePages generates a whole file hierarchy, this method returns the current filename,
+      """since RawFile generates a whole file hierarchy, this method returns the current filename,
       which may change over the lifetime of this object"""
 
@@ -27,13 +26,13 @@ class RawFilePages(Page):
 
    def title(self):
-      """since RawFilePages generates a while file hierarchy, this method returns the current title,
+      """since RawFile generates a while file hierarchy, this method returns the current title,
       which may change over the lifetime of this object"""
 





More information about the Synopsis-changes mailing list